TickSchemeError

Enum TickSchemeError 

pub enum TickSchemeError {
Show 14 variants TickNotFinite { tick: f64, }, TickNotPositive { tick: f64, }, EmptyTiers, TierValuesNaN { index: usize, start: f64, stop: f64, step: f64, }, TierStartNotLessThanStop { index: usize, start: f64, stop: f64, }, TierStepNotPositive { index: usize, step: f64, }, TierStepNotLessThanRange { index: usize, start: f64, stop: f64, step: f64, range: f64, }, TierOverlapsPrevious { index: usize, start: f64, prev_stop: f64, }, TierStartOutsidePriceRange { index: usize, start: f64, }, TierStopOutsidePriceRange { index: usize, stop: f64, }, InvalidPrecision { source: CorrectnessError, }, EmptyTickExpansion, ExpandedTickOutsidePriceRange { value: f64, }, UnknownName { name: String, },
}
Error returned when tick scheme construction or parsing fails.

Variants



TickNotFinite

A fixed tick size was not finite.

Fields

tick: f64

The invalid tick size.



TickNotPositive

A fixed tick size was not positive.

Fields

tick: f64

The invalid tick size.



EmptyTiers

No tier definitions were supplied.



TierValuesNaN

A tier contained a NaN value.

Fields

index: usize

The invalid tier index.

start: f64

The tier start value.

stop: f64

The tier stop value.

step: f64

The tier step value.



TierStartNotLessThanStop

A tier start was not less than its stop.

Fields

index: usize

The invalid tier index.

start: f64

The tier start value.

stop: f64

The tier stop value.



TierStepNotPositive

A tier step was not positive.

Fields

index: usize

The invalid tier index.

step: f64

The tier step value.



TierStepNotLessThanRange

A finite tier step was not smaller than the tier range.

Fields

index: usize

The invalid tier index.

start: f64

The tier start value.

stop: f64

The tier stop value.

step: f64

The tier step value.

range: f64

The tier range.



TierOverlapsPrevious

A tier overlaps the previous tier.

Fields

index: usize

The invalid tier index.

start: f64

The tier start value.

prev_stop: f64

The previous tier stop value.



TierStartOutsidePriceRange

A tier start was outside the representable price range.

Fields

index: usize

The invalid tier index.

start: f64

The tier start value.



TierStopOutsidePriceRange

A tier stop was outside the representable price range.

Fields

index: usize

The invalid tier index.

stop: f64

The tier stop value.



InvalidPrecision

The requested price precision is invalid.

Fields

source: CorrectnessError

The source correctness error.



EmptyTickExpansion

Tier expansion produced no ticks.



ExpandedTickOutsidePriceRange

An expanded tick value was outside the representable price range.

Fields

value: f64

The invalid expanded tick value.



UnknownName

The requested tick scheme name is not registered.

Fields

name: String

The requested tick scheme name.